@@ -33,7 +33,6 @@ class Site(collections.Mapping, collections.Hashable, MSONable):
     coordinates.
     """
 
-    supported_properties = ("magmom", "charge", "coordination_no", "forces")
     position_atol = 1e-5
 
     def __init__(self, atoms_n_occu, coords, properties=None):
@@ -70,9 +69,6 @@ class Site(collections.Mapping, collections.Hashable, MSONable):
 
         self._coords = coords
         self._properties = properties if properties else {}
-        for k in self._properties.keys():
-            if k not in Site.supported_properties:
-                raise ValueError("{} is not a supported property".format(k))
 
     @property
     def properties(self):
@@ -195,7 +191,7 @@ class Site(collections.Mapping, collections.Hashable, MSONable):
         if other is None:
             return False
         return self._species == other._species and \
-            np.allclose(self._coords, other._coords, 
+            np.allclose(self._coords, other._coords,
                         atol=Site.position_atol) and \
             self._properties == other._properties
 
@@ -238,6 +234,10 @@ class Site(collections.Mapping, collections.Hashable, MSONable):
         if self._species.average_electroneg > \
                 other._species.average_electroneg:
             return 1
+        if self.species_string < other.species_string:
+            return -1
+        if self.species_string > other.species_string:
+            return 1
         return 0
 
     def __str__(self):
@@ -388,7 +388,7 @@ class PeriodicSite(Site, MSONable):
     def __eq__(self, other):
         return self._species == other._species and \
             self._lattice == other._lattice and \
-            np.allclose(self._coords, other._coords, 
+            np.allclose(self._coords, other._coords,
                         atol=Site.position_atol) and \
             self._properties == other._properties
 
