@@ -111,7 +111,8 @@ class SiteCollection(collections.Sequence):
         List of types of specie. Only works for ordered structures.
         Disordered structures will raise an AttributeError.
         """
-        types = []  # Cannot use sets since we want a deterministic algorithm.
+        # Cannot use set since we want a deterministic algorithm.
+        types = []
         for site in self:
             if site.specie not in types:
                 types.append(site.specie)
@@ -124,6 +125,25 @@ class SiteCollection(collections.Sequence):
                 if site.specie == t:
                     yield site
 
+    def indices_from_symbol(self, symbol):
+        """
+        Returns a tuple with the sequential indices of the sites
+        that contain an element with the given chemical symbol.
+        """
+        indices = []
+        for i, specie in enumerate(self.species):
+            if specie.symbol == symbol:
+                indices.append(i)
+        return tuple(indices)
+
+    @property
+    def symbol_set(self):
+        """
+        Tuple with the set of chemical symbols.
+        Note that len(symbol_set) == len(types_of_specie)
+        """
+        return tuple([specie.symbol for specie in self.types_of_specie])
+
     @property
     def atomic_numbers(self):
         """List of atomic numbers."""
@@ -382,6 +402,13 @@ class IStructure(SiteCollection, MSONable):
         """
         return self._lattice
 
+    @property
+    def reciprocal_lattice(self):
+        """
+        Reciprocal lattice of the structure.
+        """
+        return self._lattice.reciprocal_lattice
+
     def lattice_vectors(self, space="r"):
         """
         Returns the vectors of the unit cell in Angstrom.
@@ -2040,10 +2067,14 @@ class Molecule(IMolecule):
             distance:
                 distance in angstroms by which to perturb each site.
         """
+        def get_rand_vec():
+            #deals with zero vectors.
+            vector = np.random.randn(3)
+            vnorm = np.linalg.norm(vector)
+            return vector / vnorm * distance if vnorm != 0 else get_rand_vec()
+
         for i in range(len(self._sites)):
-            vector = np.random.rand(3)
-            vector /= np.linalg.norm(vector) / distance
-            self.translate_sites([i], vector)
+            self.translate_sites([i], get_rand_vec())
 
     def apply_operation(self, symmop):
         """
@@ -2152,5 +2183,3 @@ class StructureError(Exception):
     Raised when the structure has problems, e.g., atoms that are too close.
     """
     pass
-
-
