@@ -1,4 +1,7 @@
-from os.path import abspath, basename, join as pj
+from __future__ import division, print_function
+
+import os
+
 from cStringIO import StringIO
 from subprocess import Popen, PIPE
 
@@ -14,41 +17,48 @@ __status__ = "Development"
 __date__ = "$Feb 21, 2013M$"
 
 __all__ = [
-"Mrgscr",
-"Mrggkk",
-"Mrgdbb",
-"Anaddb",
+    "Mrgscr",
+    "Mrggkk",
+    "Mrgdbb",
+    "Anaddb",
 ]
 
-##########################################################################################
 
 class ExecWrapper(object):
+    """This class runs an executable in a subprocess."""
+    def __init__(self, executable, verbose=0):
+        """
+        Args:
+            executable:
+                path to the executable.
+            verbose:
+                Verbosity level
+        """
+        if executable is None: executable = self.name
 
-    def __init__(self, executable=None, verbose=0):
-
-        self.executable = executable
-        if executable is None:
-            self.executable = pj(abipy_env.bindir, self._name)
-
-        self.executable = which(self.executable)
-
-        if self.executable is None:
-            raise self.Error("%s is not executable" % self.executable)
-        assert basename(self.executable) == self._name
+        self.executable = which(executable)
 
         self.verbose = int(verbose)
 
+        if self.executable is None:
+            msg = "Cannot find executable %s is PATH\n Use export PATH=/dir_with_exec:$PATH" % executable
+            raise self.Error(msg)
+
+        assert os.path.basename(self.executable) == self._name
+
     def __str__(self):
         return "%s" % self.executable
 
-    def execute(self, **kwargs):
+    @property
+    def name(self):
+        return self._name
 
+    def execute(self, cwd=None, **kwargs):
+        """Execute the executable in a subprocess."""
         args = [self.executable, "<", self.stdin_fname, ">", self.stdout_fname, "2>", self.stderr_fname]
 
         self.cmd_str = " ".join(args)
 
-        cwd = kwargs.get("cwd", None)
-
         p = Popen(self.cmd_str, shell=True, stdout=PIPE, stderr=PIPE, cwd=cwd)
 
         (self.stdout_data, self.stderr_data) = p.communicate()
@@ -60,17 +70,18 @@ class ExecWrapper(object):
                 self.stdout_data = out.read()
                 self.stderr_data = err.read()
             if self.verbose:
-                print "*** stdout: ***\n", self.stdout_data
-                print "*** stderr  ***\n", self.stderr_data
+                print("*** stdout: ***\n", self.stdout_data)
+                print("*** stderr  ***\n", self.stderr_data)
             raise self.Error("%s returned %s\n cmd_str: %s" % (self, self.returncode, self.cmd_str))
 
 ##########################################################################################
 
+
 class Mrgscr(ExecWrapper):
     _name = "mrgscr"
 
-    class MrgscrError(Exception): 
-        pass
+    class MrgscrError(Exception):
+        """Error class for Mrgscr"""
 
     Error = MrgscrError
 
@@ -79,29 +90,29 @@ class Mrgscr(ExecWrapper):
         Execute mrgscr in a subprocess to merge files_to_merge. Produce new file with prefix out_prefix
 
         If cwd is not None, the child's current directory will be changed to cwd before it is executed.
-
-        :return: Exit status of the subprocess.
         """
         # We work with absolute paths.
-        files_to_merge = [ abspath(s) for s in list_strings(files_to_merge) ]
+        files_to_merge = [os.path.abspath(s) for s in list_strings(files_to_merge)]
         nfiles = len(files_to_merge)
 
         if self.verbose:
-            print "Will merge %d files with output_prefix %s" % (nfiles, out_prefix)
-            for (i,f) in enumerate(files_to_merge): print " [%d] %s" % (i, f)
+            print("Will merge %d files with output_prefix %s" % (nfiles, out_prefix))
+            for (i, f) in enumerate(files_to_merge):
+                print(" [%d] %s" % (i, f))
 
         if nfiles == 1:
             raise self.Error("merge_qpoints does not support nfiles == 1")
 
-        self.stdin_fname, self.stdout_fname, self.stderr_fname = "mrgscr.stdin", "mrgscr.stdout", "mrgscr.stderr"
+        self.stdin_fname, self.stdout_fname, self.stderr_fname = (
+            "mrgscr.stdin", "mrgscr.stdout", "mrgscr.stderr")
         if cwd is not None:
             self.stdin_fname, self.stdout_fname, self.stderr_fname = \
-            map(pj, 3*[cwd], [self.stdin_fname, self.stdout_fname, self.stderr_fname])
+                map(pj, 3 * [cwd], [self.stdin_fname, self.stdout_fname, self.stderr_fname])
 
         inp = StringIO()
 
-        inp.write(str(nfiles)+"\n")      # Number of files to merge.
-        inp.write(out_prefix +"\n")      # Prefix for the final output file:
+        inp.write(str(nfiles) + "\n")      # Number of files to merge.
+        inp.write(out_prefix + "\n")      # Prefix for the final output file:
 
         for filename in files_to_merge:
             inp.write(filename + "\n")   # List with the files to merge.
@@ -121,45 +132,47 @@ class Mrgscr(ExecWrapper):
 
 ##########################################################################################
 
+
 class Mrggkk(ExecWrapper):
     _name = "mrggkk"
 
-    class MrggkkError(Exception): 
-        pass
+    class MrggkkError(Exception):
+        """Error class for Mrggkk."""
 
     Error = MrggkkError
 
     def merge(self, gswfk_file, dfpt_files, gkk_files, out_fname, binascii=0, cwd=None):
-        "Merge DDB file, return the absolute path of the new database"
-        #
+        """Merge DDB file, return the absolute path of the new database."""
         raise NotImplementedError("This method should be tested")
 
-        out_fname = out_fname if cwd is None else pj(abspath(cwd), out_fname)
+        out_fname = out_fname if cwd is None else os.path.join(os.path.abspath(cwd), out_fname)
 
         # We work with absolute paths.
         gswfk_file = absath(gswfk_file)
-        dfpt_files = [ abspath(s) for s in list_strings(dfpt_files) ]
-        gkk_files  = [ abspath(s) for s in list_strings(gkk_files) ]
+        dfpt_files = [os.path.abspath(s) for s in list_strings(dfpt_files)]
+        gkk_files = [os.path.abspath(s) for s in list_strings(gkk_files)]
 
         if self.verbose:
-            print "Will merge %d 1WF files, %d GKK file in output %s" % (len(dfpt_nfiles), (len_gkk_files), out_fname)
-            for (i,f) in enumerate(dfpt_files): print " [%d] 1WF %s" % (i, f)
-            for (i,f) in enumerate(gkk_files):  print " [%d] GKK %s" % (i, f)
+            print("Will merge %d 1WF files, %d GKK file in output %s" %
+                  (len(dfpt_nfiles), (len_gkk_files), out_fname))
+            for (i, f) in enumerate(dfpt_files): print(" [%d] 1WF %s" % (i, f))
+            for (i, f) in enumerate(gkk_files):  print(" [%d] GKK %s" % (i, f))
 
-        self.stdin_fname, self.stdout_fname, self.stderr_fname = "mrggkk.stdin", "mrggkk.stdout", "mrggkk.stderr"
+        self.stdin_fname, self.stdout_fname, self.stderr_fname = (
+            "mrggkk.stdin", "mrggkk.stdout", "mrggkk.stderr")
         if cwd is not None:
             self.stdin_fname, self.stdout_fname, self.stderr_fname = \
-            map(pj, 3*[cwd], [self.stdin_fname, self.stdout_fname, self.stderr_fname])
+                map(pj, 3 * [cwd], [self.stdin_fname, self.stdout_fname, self.stderr_fname])
 
         inp = StringIO()
 
-        inp.write(out_fname+"\n")        # Name of the output file
-        inp.write(str(binascii)+"\n")    # Integer flag: 0 --> binary output, 1 --> ascii formatted output
-        inp.write(gswfk_file+"\n")       # Name of the groud state wavefunction file WF
+        inp.write(out_fname + "\n")        # Name of the output file
+        inp.write(str(binascii) + "\n")    # Integer flag: 0 --> binary output, 1 --> ascii formatted output
+        inp.write(gswfk_file + "\n")       # Name of the groud state wavefunction file WF
 
         #dims = len(dfpt_files, gkk_files, ?)
         dims = " ".join([str(d) for d in dims])
-        inp.write(dims+"\n")             # Number of 1WF, of GKK files, and number of 1WF files in all the GKK files
+        inp.write(dims + "\n")             # Number of 1WF, of GKK files, and number of 1WF files in all the GKK files
 
         # Names of the 1WF files...
         for fname in dfpt_files: inp.write(fname + "\n")
@@ -182,43 +195,47 @@ class Mrggkk(ExecWrapper):
 
 ##########################################################################################
 
+
 class Mrgddb(ExecWrapper):
     _name = "mrgddb"
 
-    class MrgddbError(Exception): 
-        pass
+    class MrgddbError(Exception):
+        """Error class for Mrgddb."""
 
     Error = MrgddbError
 
-    def merge(self, ddb_files, out_fname, description, cwd=None):
-        "Merge DDB file, return the absolute path of the new database"
+    def merge(self, ddb_files, out_ddb, description, cwd=None):
+        """Merge DDB file, return the absolute path of the new database."""
 
         # We work with absolute paths.
-        ddb_files = [ abspath(s) for s in list_strings(ddb_files) ]
+        ddb_files = [os.path.abspath(s) for s in list_strings(ddb_files)]
 
-        out_fname = out_fname if cwd is None else pj(abspath(cwd), out_fname)
+        out_ddb = out_ddb if cwd is None else os.path.join(os.path.abspath(cwd), out_ddb)
 
         if self.verbose:
-            print "Will merge %d files with output_prefix %s" % (len(ddb_files), out_fname)
-            for (i,f) in enumerate(ddb_files): print " [%d] %s" % (i, f)
+            print("Will merge %d files into output DDB %s" % (len(ddb_files), out_ddb))
+            for (i, f) in enumerate(ddb_files):
+                print(" [%d] %s" % (i, f))
 
         # Handle the case of a single file since mrgddb uses 1 to denote GS files!
         if len(ddb_files) == 1:
-            with open(ddb_files[0], "r") as inh, open(out_fname, "w") as out:
+            with open(ddb_files[0], "r") as inh, open(out_ddb, "w") as out:
                 for line in inh:
                     out.write(line)
-            return out_fname
+            return out_ddb
+
+        self.stdin_fname, self.stdout_fname, self.stderr_fname = (
+            "mrgddb.stdin", "mrgddb.stdout", "mrgddb.stderr")
 
-        self.stdin_fname, self.stdout_fname, self.stderr_fname = "mrgddb.stdin", "mrgddb.stdout", "mrgddb.stderr"
         if cwd is not None:
             self.stdin_fname, self.stdout_fname, self.stderr_fname = \
-            map(pj, 3*[cwd], [self.stdin_fname, self.stdout_fname, self.stderr_fname])
+                map(pj, 3 * [cwd], [self.stdin_fname, self.stdout_fname, self.stderr_fname])
 
         inp = StringIO()
 
-        inp.write(out_fname+"\n")            # Name of the output file.
-        inp.write(str(description)+"\n")     # Description.
-        inp.write(str(len(ddb_files))+"\n")  # Number of input DDBs.
+        inp.write(out_ddb + "\n")            # Name of the output file.
+        inp.write(str(description) + "\n")     # Description.
+        inp.write(str(len(ddb_files)) + "\n")  # Number of input DDBs.
 
         # Names of the DDB files.
         for fname in ddb_files:
@@ -235,39 +252,54 @@ class Mrgddb(ExecWrapper):
         except self.Error:
             raise
 
-        return out_fname
+        return out_ddb
 
 ##########################################################################################
 
+
 class Anaddb(ExecWrapper):
     _name = "anaddb"
 
-    class AnaddbError(Exception): 
-        pass
+    class AnaddbError(Exception):
+        """Error class for Anaddb."""
 
     Error = AnaddbError
 
+    #def make_stdin(self):
+    #    # Files file
+    #    inp = StringIO()
+    #    inp.write(self.input_fname + "\n")     # Input file.
+    #    inp.write(self.stdout_fname + "\n")    # Output file.
+    #    inp.write(ddb_file + "\n")             # DDB file
+    #    inp.write("dummy_band2eps" + "\n")
+    #    inp.write("dummy1" + "\n")
+    #    inp.write("dummy2" + "\n")
+    #    inp.write("dummy3" + "\n")
+    #    inp.seek(0)
+    #    self.stdin_data = [s for s in inp]
+
     def diagonalize_1q(self, ddb_file, cwd=None):
 
         # We work with absolute paths.
-        ddb_file = abspath(ddb_file)
+        ddb_file = os.path.abspath(ddb_file)
+
+        self.stdin_fname, self.input_fname, self.stdout_fname, self.stderr_fname = (
+            "anaddb.stdin", "anaddb.input", "anaddb.stdout", "anaddb.stderr")
 
-        self.stdin_fname, self.input_fname, self.stdout_fname, self.stderr_fname = \
-        "anaddb.stdin", "anaddb.input", "anaddb.stdout", "anaddb.stderr"
         if cwd is not None:
             self.stdin_fname, self.input_fname, self.stdout_fname, self.stderr_fname = \
-            map(pj, 3*[cwd], [self.stdin_fname, self.inp_fname, self.stdout_fname, self.stderr_fname])
+                map(pj, 3 * [cwd], [self.stdin_fname, self.inp_fname, self.stdout_fname, self.stderr_fname])
 
         # Files file
         inp = StringIO()
 
-        inp.write(self.input_fname+"\n")     # Input file.
-        inp.write(self.stdout_fname+"\n")    # Output file.
-        inp.write(ddb_file+"\n")             # DDB file
-        inp.write("dummy_band2eps"+"\n")
-        inp.write("dummy1"+"\n")
-        inp.write("dummy2"+"\n")
-        inp.write("dummy3"+"\n")
+        inp.write(self.input_fname + "\n")     # Input file.
+        inp.write(self.stdout_fname + "\n")    # Output file.
+        inp.write(ddb_file + "\n")             # DDB file
+        inp.write("dummy_band2eps" + "\n")
+        inp.write("dummy1" + "\n")
+        inp.write("dummy2" + "\n")
+        inp.write("dummy3" + "\n")
 
         inp.seek(0)
         self.stdin_data = [s for s in inp]
@@ -280,9 +312,9 @@ class Anaddb(ExecWrapper):
             nfound = 0
             tag = " qpt "
             for line in fh:
-                print line
+                print(line)
                 if line.startswith(tag):
-                    nfound +=1
+                    nfound += 1
                     # Coordinates of the q-points.
                     qcoords_str = line.split()[1:4]
                     #qcoords_str = [ s.replace("D", "E") for s in qcoords_str]
@@ -314,7 +346,8 @@ class Anaddb(ExecWrapper):
             #inp.write('# This line added when defaults were changed (v5.3) to keep the previous, old behaviour
             #inp.write('#  symdynmat 0
 
-        if self.verbose: print "Will diagonalize DDB file : %s" % ddb_file
+        if self.verbose:
+            print("Will diagonalize DDB file : %s" % ddb_file)
 
         try:
             self.execute(cwd=cwd)
@@ -322,9 +355,9 @@ class Anaddb(ExecWrapper):
             raise
 
         # Get frequencies from the output file
-        with open(self.stdout_fname, "r") as out:
-            print out.readlines()
+        # TODO
+        #with open(self.stdout_fname, "r") as out:
+            #print(out.readlines())
             #for line in out:
             #    if line: raise
-
-        #return frequencies
+            #return frequencies
