@@ -303,10 +303,10 @@ class DictVaspInputSet(AbstractVaspInputSet):
             "@module": self.__module__.__name__,
         }
 
-    @staticmethod
-    def from_dict(d):
-        return DictVaspInputSet(d["name"], d["config_dict"],
-                                d["constrain_total_magmom"])
+    @classmethod
+    def from_dict(cls, d):
+        return cls(d["name"], d["config_dict"],
+                   d["constrain_total_magmom"])
 
 
 class VaspInputSet(DictVaspInputSet):
@@ -365,11 +365,11 @@ class VaspInputSet(DictVaspInputSet):
             "@module": self.__module__.__name__,
         }
 
-    @staticmethod
-    def from_dict(d):
-        return VaspInputSet(d["name"], d["config_file"],
-                            user_incar_settings=d["user_incar_settings"],
-                            constrain_total_magmom=d["constrain_total_magmom"])
+    @classmethod
+    def from_dict(cls, d):
+        return cls(d["name"], d["config_file"],
+                   user_incar_settings=d["user_incar_settings"],
+                   constrain_total_magmom=d["constrain_total_magmom"])
 
 
 class MITVaspInputSet(VaspInputSet):
@@ -405,11 +405,10 @@ class MITVaspInputSet(VaspInputSet):
             "@module": self.__class__.__module__,
         }
 
-    @staticmethod
-    def from_dict(d):
-        return MITVaspInputSet(
-            user_incar_settings=d["user_incar_settings"],
-            constrain_total_magmom=d["constrain_total_magmom"])
+    @classmethod
+    def from_dict(cls, d):
+        return cls(user_incar_settings=d["user_incar_settings"],
+                   constrain_total_magmom=d["constrain_total_magmom"])
 
 
 class MITGGAVaspInputSet(VaspInputSet):
@@ -443,11 +442,10 @@ class MITGGAVaspInputSet(VaspInputSet):
             "@module": self.__class__.__module__,
         }
 
-    @staticmethod
-    def from_dict(d):
-        return MITGGAVaspInputSet(
-            user_incar_settings=d["user_incar_settings"],
-            constrain_total_magmom=d["constrain_total_magmom"])
+    @classmethod
+    def from_dict(cls, d):
+        return cls(user_incar_settings=d["user_incar_settings"],
+                   constrain_total_magmom=d["constrain_total_magmom"])
 
 
 class MITHSEVaspInputSet(VaspInputSet):
@@ -473,11 +471,10 @@ class MITHSEVaspInputSet(VaspInputSet):
             "@module": self.__class__.__module__,
         }
 
-    @staticmethod
-    def from_dict(d):
-        return MITHSEVaspInputSet(
-            user_incar_settings=d["user_incar_settings"],
-            constrain_total_magmom=d["constrain_total_magmom"])
+    @classmethod
+    def from_dict(cls, d):
+        return cls(user_incar_settings=d["user_incar_settings"],
+                   constrain_total_magmom=d["constrain_total_magmom"])
 
 
 class MITMDVaspInputSet(VaspInputSet):
@@ -559,12 +556,12 @@ class MITMDVaspInputSet(VaspInputSet):
             "@module": self.__class__.__module__,
         }
 
-    @staticmethod
-    def from_dict(d):
-        return MITMDVaspInputSet(
-            start_temp=d["start_temp"], end_temp=d["end_temp"],
-            nsteps=d["nsteps"], time_step=d["time_step"], prec=d["prec"],
-            ggau=d["ggau"], user_incar_settings=d["user_incar_settings"])
+    @classmethod
+    def from_dict(cls, d):
+        return cls(start_temp=d["start_temp"], end_temp=d["end_temp"],
+                   nsteps=d["nsteps"], time_step=d["time_step"],
+                   prec=d["prec"], ggau=d["ggau"],
+                   user_incar_settings=d["user_incar_settings"])
 
 
 class MPVaspInputSet(DictVaspInputSet):
@@ -595,9 +592,9 @@ class MPVaspInputSet(DictVaspInputSet):
             "@module": self.__class__.__module__,
         }
 
-    @staticmethod
-    def from_dict(d):
-        return MPVaspInputSet(
+    @classmethod
+    def from_dict(cls, d):
+        return cls(
             user_incar_settings=d["user_incar_settings"],
             constrain_total_magmom=d["constrain_total_magmom"])
 
@@ -635,11 +632,10 @@ class MPGGAVaspInputSet(DictVaspInputSet):
             "@module": self.__class__.__module__,
         }
 
-    @staticmethod
-    def from_dict(d):
-        return MPGGAVaspInputSet(
-            user_incar_settings=d["user_incar_settings"],
-            constrain_total_magmom=d["constrain_total_magmom"])
+    @classmethod
+    def from_dict(cls, d):
+        return cls(user_incar_settings=d["user_incar_settings"],
+                   constrain_total_magmom=d["constrain_total_magmom"])
 
 
 class MPStaticVaspInputSet(MPVaspInputSet):
@@ -686,7 +682,7 @@ class MPStaticVaspInputSet(MPVaspInputSet):
 
     @staticmethod
     def get_structure(vasp_run, outcar=None, initial_structure=False,
-                      refined_structure=False):
+                      additional_info=False):
         """
         Process structure for static calculations from previous run.
 
@@ -700,8 +696,12 @@ class MPStaticVaspInputSet(MPVaspInputSet):
             initial_structure:
                 Whether to return the structure from previous run. Default is
                 False.
-            refined_structure:
-                Whether to return the refined structure (conventional cell)
+            additional_info:
+                Whether to return additional symmetry info related to the
+                structure. If True, return a list of the refined structure (
+                conventional cell), the conventional standard structure,
+                the symmetry dataset and symmetry operations of the structure
+                (see SymmetryFinder doc for details)
 
         Returns:
             Returns the magmom-decorated structure that can be passed to get
@@ -723,9 +723,13 @@ class MPStaticVaspInputSet(MPVaspInputSet):
         sym_finder = SymmetryFinder(structure, symprec=0.01)
         if initial_structure:
             return structure
-        elif refined_structure:
-            return (sym_finder.get_primitive_standard_structure(),
-                    sym_finder.get_refined_structure())
+        elif additional_info:
+            info = [sym_finder.get_refined_structure(),
+                    sym_finder.get_conventional_standard_structure(),
+                    sym_finder.get_symmetry_dataset(),
+                    sym_finder.get_symmetry_operations()]
+            return [sym_finder.get_primitive_standard_structure(),
+                    info]
         else:
             return sym_finder.get_primitive_standard_structure()
 
@@ -862,6 +866,11 @@ class MPNonSCFVaspInputSet(MPStaticVaspInputSet):
                              * 1.2))
         return {"ISPIN": ispin, "NBANDS": nbands}
 
+    def get_incar(self, structure):
+        incar = super(MPNonSCFVaspInputSet, self).get_incar(structure)
+        incar.pop("MAGMOM", None)
+        return incar
+
     @staticmethod
     def from_previous_vasp_run(previous_vasp_dir, output_dir='.',
                                mode="Uniform", user_incar_settings=None,
