@@ -61,15 +61,16 @@ class MSONable(object):
         pass
 
     @classmethod
-    @abstractmethod
     def from_dict(cls, d):
         """
-        This simply raises a NotImplementedError to force subclasses to
-        implement this static method. Abstract static methods are not
-        implemented until Python 3+.
+        This implements a default from_dict method which supports all
+        classes that simply saves all init arguments in a "init_args"
+        key. Otherwise, the MSONAble class must override this class method.
         """
-        raise NotImplementedError("MSONable objects must implement a from_dict"
-                                  " static method.")
+        if "init_args" in d:
+            return cls(**d['init_args'])
+        raise MSONError("Invalid dict for default from_dict. Please "
+                        "override from_dict for ".format(cls))
 
     @property
     def to_json(self):
@@ -161,16 +162,21 @@ class PMGJSONDecoder(json.JSONDecoder):
                 classname = None
             if modname:
                 if modname == "datetime" and classname == "datetime":
-                    return datetime.datetime.strptime(d["string"],
-                                                      "%Y-%m-%d %H:%M:%S.%f")
+                    try:
+                        dt = datetime.datetime.strptime(d["string"],
+                                                        "%Y-%m-%d %H:%M:%S.%f")
+                    except ValueError:
+                        dt = datetime.datetime.strptime(d["string"],
+                                                      "%Y-%m-%d %H:%M:%S")
+                    return dt
                 mod = __import__(modname, globals(), locals(), [classname], -1)
                 if hasattr(mod, classname):
-                    cls = getattr(mod, classname)
+                    cls_ = getattr(mod, classname)
                     data = {k: v for k, v in d.items()
                             if k not in ["module", "class",
                                          "@module", "@class"]}
-                    if hasattr(cls, "from_dict"):
-                        return cls.from_dict(data)
+                    if hasattr(cls_, "from_dict"):
+                        return cls_.from_dict(data)
             return {self.process_decoded(k): self.process_decoded(v)
                     for k, v in d.items()}
         elif isinstance(d, list):
@@ -182,6 +188,13 @@ class PMGJSONDecoder(json.JSONDecoder):
         return self.process_decoded(d)
 
 
+class MSONError(Exception):
+    """
+    Exception class for serialization errors.
+    """
+    pass
+
+
 def json_pretty_dump(obj, filename):
     """
     Serialize obj as a JSON formatted stream to the given filename (
@@ -197,3 +210,38 @@ def json_load(filename):
     """
     with open(filename, "r") as fh:
         return json.load(fh)
+
+
+def pmg_load(filename, **kwargs):
+    """
+    Loads a json file and deserialize it with PMGJSONDecoder.
+
+    Args:
+        filename:
+            Filename of file to open. Can be gzipped or bzipped.
+        \*\*kwargs:
+            Any of the keyword arguments supported by the json.load method.
+
+    Returns:
+        Deserialized pymatgen object. Note that these objects can be lists,
+        dicts or otherwise nested pymatgen objects that support the to_dict
+        and from_dict MSONAble protocol.
+    """
+    return json.load(zopen(filename), cls=PMGJSONDecoder, **kwargs)
+
+
+def pmg_dump(obj, filename, **kwargs):
+    """
+    Dump an object to a json file using PMGJSONEncoder. Note that these
+    objects can be lists, dicts or otherwise nested pymatgen objects that
+    support the to_dict and from_dict MSONAble protocol.
+
+    Args:
+        obj:
+            Object to dump.
+        filename:
+            Filename of file to open. Can be gzipped or bzipped.
+        \*\*kwargs:
+            Any of the keyword arguments supported by the json.load method.
+    """
+    return json.dump(obj, zopen(filename, "w"), cls=PMGJSONEncoder, **kwargs)
