@@ -158,7 +158,10 @@ def plot_dos(args):
 
     plotter = DosPlotter()
     plotter.add_dos_dict(all_dos)
-    plotter.show()
+    if args.file:
+        plotter.get_plot().savefig(args.file[0])
+    else:
+        plotter.show()
 
 
 def plot_chgint(args):
@@ -368,14 +371,16 @@ if __name__ == "__main__":
     parser_plot.add_argument("filename", metavar="filename", type=str, nargs=1,
                              help="vasprun.xml file to plot")
     parser_plot.add_argument("-s", "--site", dest="site", action="store_const",
-                             const=True, help="plot site projected DOS")
+                             const=True, help="Plot site projected DOS")
     parser_plot.add_argument("-e", "--element", dest="element", type=str,
                              nargs=1,
                              help="List of elements to plot as comma-separated"
                              " values e.g., Fe,Mn")
     parser_plot.add_argument("-o", "--orbital", dest="orbital",
                              action="store_const", const=True,
-                             help="plot orbital projected DOS")
+                             help="Plot orbital projected DOS")
+    parser_plot.add_argument("-f", "--file", dest="file", type=str, nargs=1,
+                             help="Save to file.")
     parser_plot.set_defaults(func=plot_dos)
 
     parser_plotchg = subparsers.add_parser("plotchgint",
